@@ -3,7 +3,7 @@
 # Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 # Copyright (c) 2016 Ashish Gulhati <biz-btc at ashish dot neomailbox.com>
 #
-# $Id: lib/Business/Bitcoin.pm v1.013 Fri Dec 30 02:13:28 2016 -0500 $
+# $Id: lib/Business/Bitcoin.pm v1.017 Wed Jan 11 00:21:59 EST 2017 $
 
 use strict;
 
@@ -18,7 +18,7 @@ use Business::Bitcoin::Request;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.013 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.017 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -26,7 +26,7 @@ sub new {
   return undef unless $args{XPUB};
   return undef if $args{StartIndex} and $args{StartIndex} =~ /\D/;
   unlink $args{DB} if $args{Clobber};
-  my $db = DBI->connect("dbi:SQLite:dbname=$args{DB}","","");
+  my $db = DBI->connect("dbi:SQLite:dbname=$args{DB}", undef, undef, {AutoCommit => 1});
   my @tables = $db->tables('%','%','requests','TABLE');
   unless ($tables[0]) {
     if ($args{Create}) {
@@ -88,8 +88,8 @@ Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 
 =head1 VERSION
 
- $Revision: 1.013 $
- $Date: Fri Dec 30 02:13:28 2016 -0500 $
+ $Revision: 1.017 $
+ $Date: Wed Jan 11 00:21:59 EST 2017 $
 
 =head1 SYNOPSIS
 
@@ -189,9 +189,9 @@ The following optional named arguments can be provided:
 Confirmations - The number of confirmations needed to verify payment
 of this request. The default is 5.
 
-Reference - Optional reference ID to be associated with the requst, to
-facilitate integration with existing ordering systems. If you provide
-a reference ID it should be unique for each request.
+Reference - Optional reference ID to be associated with the request,
+to facilitate integration with existing ordering systems. If a
+reference ID is provided it should be unique for each request.
 
 =back
 
